==> silentbob-2.3.tar.gz: silentbob-2.3/src/editors.cxx <==
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2006
 * graycardinalster@gmail.com
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <gclib/gclib.h>
#include <sys/wait.h>
#include <mod.h>
#include <head.h>
#include <dbg.h>

#define TMP_FILE "/tmp/.silent_bob.tmp.cpp"

void try_editor ()
{
	int pid;
	int fd;
	int status;
	char m_buf[1024];
	
	pid = fork ();
	if (pid < 0)
		return;

	if (pid == 0) {
		unlink (TMP_FILE);
		fd = open (TMP_FILE, O_WRONLY | O_CREAT);
		fchmod (fd, S_IREAD | S_IWRITE);
		if (fd == -1) {
			perror ("open");
			exit (1);
		}
		dup2 (fd, fileno (stdout));
		return;
	} else {
		if ((waitpid (pid, &status, 0) < 0) ||
			status != 0) 
			exit (status);
		
		sprintf (m_buf, "%s %s", ENV->editor, TMP_FILE);
		system (m_buf);
		exit (0);
	}
}

char * editor_option (char * name)
{
	if (! name)
		return NULL;

	if (EQ(name, "-g") || EQ(name, "--gvim")) 
		ENV->editor = (char *) "gvim";

	if (EQ(name, "--emacs"))
		ENV->editor = (char *) "emacs";

	if (EQ(name, "--nano"))
		ENV->editor = (char *) "nano";

	return ENV->editor;
}

==> silentbob-2.4.1.tar.gz: silentbob-2.4.1/src/editors.cxx <==
/*
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 1, or (at your option)
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
 * (c) Oleg Puchinin 2006
 * graycardinalster@gmail.com
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <fcntl.h>
#include <gclib/gclib.h>
#include <sys/wait.h>
#include <mod.h>
#include <head.h>
#include <dbg.h>

#define TMP_FILE "/tmp/.silent_bob.tmp.cpp"

void try_editor ()
{
	int pid;
	int fd;
	int status;
	char m_buf[1024];
	
	pid = fork ();
	if (pid < 0)
		return;

	if (pid == 0) {
		unlink (TMP_FILE);
		fd = open (TMP_FILE, O_WRONLY | O_CREAT, 0666);
		fchmod (fd, S_IREAD | S_IWRITE);
		if (fd == -1) {
			perror ("open");
			exit (1);
		}
		dup2 (fd, fileno (stdout));
		return;
	} else {
		if ((waitpid (pid, &status, 0) < 0) ||
			status != 0) 
			exit (status);
		
		sprintf (m_buf, "%s %s", ENV->editor, TMP_FILE);
		system (m_buf);
		exit (0);
	}
}

char * editor_option (char * name)
{
	if (! name)
		return NULL;

	if (EQ(name, "-g") || EQ(name, "--gvim")) 
		ENV->editor = (char *) "gvim";

	if (EQ(name, "--emacs"))
		ENV->editor = (char *) "emacs";

	if (EQ(name, "--nano"))
		ENV->editor = (char *) "nano";

	return ENV->editor;
}
